@@ -1,5 +1,5 @@
 ##++
-##     CGI Lite v2.99_03
+##     CGI Lite v2.99_04
 ##
 ##     see separate CHANGES file for detailed history
 ##
@@ -254,8 +254,8 @@ prior to version 3.0.
 
 	my $this_type = $cgi->get_upload_type ($field);
 
-Returns the MIME type as a scalar string or undef if the argument does
-not exist or has no type.
+Returns the MIME type as a scalar string if single valued, an arrayref
+if multi-valued or undef if the argument does not exist or has no type.
 
 =item B<set_file_type>
 
@@ -483,7 +483,7 @@ future. Non-method use will trigger a warning.
 
 =head1 VERSIONS
 
-This module has maintained backwards compatibility with versions of
+This module maintained backwards compatibility with versions of
 Perl back to 5.002 for a very long time. Such stability is a welcome
 attribute but it restricts the code by disallowing access to features
 introduced into the language since 1996.
@@ -505,13 +505,13 @@ the request tracker at L<https://rt.cpan.org/Public/Dist/Display.html?Name=CGI-L
 =head1 SEE ALSO
 
 If you're looking for more comprehensive CGI modules, you can either use
-the CGI::* modules or L<CGI.pm|CGI>. Both are maintained by
-L<Dr. Lincoln Stein|http://search.cpan.org/CPAN/authors/id/L/LD/LDS/>
-and can be found at your local CPAN mirror.
+the CGI::* modules or L<CGI.pm|CGI>. 
 
-L<CGI::Lite::Request> uses similar method names to CGI.pm thus allowing
-easy transition between them. It uses this module as a
-dependency.
+L<CGI::Lite::Request> uses some similar method names to CGI.pm thus allowing
+easy transition between the two. It uses CGI::Lite as a dependency.
+
+L<CGI::Simple>, L<CGI::Minimal> and L<CGI::Thin> are alternative
+lightweight CGI implementations.
 
 =head1 REPOSITORY
 
@@ -591,7 +591,7 @@ BEGIN {
 	our @EXPORT = qw/browser_escape url_encode url_decode is_dangerous/;
 }
 
-our $VERSION = '2.99_03';
+our $VERSION = '2.99_04';
 
 ##++
 ##  Start
@@ -1237,7 +1237,14 @@ sub _parse_multipart_data
 					($field) = $disposition =~ /name="([^"]+)"/;
 					++$seen->{$field};
 
-					$self->{'mime_types'}->{$field} = $mime_type;
+					unless ($self->{'mime_types'}->{$field}) {
+						$self->{'mime_types'}->{$field} = $mime_type;
+					} elsif (ref $self->{'mime_types'}->{$field}) {
+						push @{$self->{'mime_types'}->{$field}}, $mime_type;
+					} else {
+						$self->{'mime_types'}->{$field} = 
+							[$self->{'mime_types'}->{$field}, $mime_type];
+					}
 
 					if ($seen->{$field} > 1) {
 						$self->{web_data}->{$field} =
@@ -1253,14 +1260,18 @@ sub _parse_multipart_data
 						$new_name =
 						  $self->_get_file_name ($platform, $directory, $file);
 
-						$self->{web_data}->{$field} = $new_name;
+						if (ref $self->{web_data}->{$field}) {
+							push @{$self->{web_data}->{$field}}, $new_name
+						} else {
+							$self->{web_data}->{$field} = $new_name;
+						}
 
 						$full_path =
 						  join ($self->{file}->{$platform}, $directory,
 							$new_name);
 
 						open ($handle, '>', $full_path)
-						  || $self->_error ("Can't create file: $full_path!");
+						  or $self->_error ("Can't create file: $full_path!");
 
 						$files->{$new_name} = $full_path;
 					}
